This function converts the data X into a pixel image
on a linear network, an object of class "linim"
(see linim).
The argument X may be any of the following:
a pixel image on a linear network, an object of class
"linim".
a pixel image, an object of class "im".
any type of data acceptable to as.im,
such as a function, numeric value, or window.
First X is converted to a pixel image object Y
(object of class "im").
The conversion is performed by as.im
using any relevant arguments specified in …. For example
the argument eps could be used to change the pixel resolution.
Next Y is converted to a pixel image on a linear network
using linim. The argument L determines the
linear network. If L is missing or NULL,
then X should be an object of class "linim",
and L defaults to the linear network on which X is defined.