clmfires is a point pattern
(object of class "ppp") containing the spatial coordinates
of each fire, with marks containing information about each fire.
There are 11 columns of marks:
cause cause of fire (see below)
burnt.area total area burned, in hectares
year calendar year of fire (factor with levels 1997-2007)
month calendar month of fire (factor with levels 1-12)
day calendar day of fire (integer 1-31)
time number of days elapsed since 1 January 1997
elevation terrain elevation in metres above sea level
orientation direction of upward slope in degrees (0-360)
slope slope of terrain
slope.discretized discretized value of slope
land.use type of land cover (see below)
}
The cause of the fire is a factor with the levels
lightning, accident (for accidents or negligence),
intentional (for intentionally started fires) and
unknown (for other causes or unknown cause). The land.use variable is a factor with levels
urban, farm (for farms or orchards),
meadow, denseforest (for dense forest),
conifer (for conifer forest or plantation),
mixedforest, grassland, bush, scrub
and artifgreen for artificial greens such as golf courses.
Accompanying this point pattern, there are two datasets
clmcov100 and clmcov200 containing covariate information
for the entire Castilla-La Mancha region. Each of these two datasets
is a list of four images (objects of class "im")
named elevation, orientation, slope and
landuse. These images provide values for the four covariates
at every location in the study area. The images in clmcov100
are 100 by 100 pixels in size, while those in clmcov200 are
200 by 200 pixels.
For easy handling, clmcov100 and clmcov200
also belong to the class "listof" so that they can be
plotted and printed immediately.
data(clmfires)clmfires is a marked point pattern (object of class "ppp").
See ppp.object. clmcov100 and clmcov200 are lists of pixel images
(objects of class "im").
plot(clmfires, which.marks="cause", cols=2:5, cex=0.25)
plot(clmcov100)Run the code above in your browser using DataLab