closing.owin(w, r, ..., polygonal=TRUE)"owin".as.mask
controlling the pixel resolution, if a pixel approximation is usedpolygonal=TRUE) or
a pixel grid approximation (polygonal=FALSE)."owin" representing the
closed window.For a small radius $r$, the closing operation has the effect of smoothing out irregularities in the boundary of $W$. For larger radii, the closing operation smooths out concave features in the boundary. For very large radii, the closed set $W*$ becomes more and more convex.
This function computes the closing of the window w
as a binary pixel mask. If w is not already a mask, it is first
converted to a mask by as.mask. The arguments
"..." determine the pixel resolution. There is a sensible
default.
The algorithm simply applies dilate.owin followed by
erode.owin.
opening.owin for the opposite operation. dilate.owin, erode.owin for the basic
operations.
owin,
as.owin for information about windows.
data(letterR)
v <- closing.owin(letterR, 0.25, dimyx=256)
plot(v, main="closing.owin")
plot(letterR, add=TRUE)Run the code above in your browser using DataLab