Learn R Programming

spatstat (version 1.63-3)

contour.imlist: Array of Contour Plots

Description

Generates an array of contour plots.

Usage

# S3 method for imlist
contour(x, …)

# S3 method for listof contour(x, …)

Arguments

x

An object of the class "imlist" representing a list of pixel images. Alternatively x may belong to the outdated class "listof".

…

Arguments passed to plot.solist to control the spatial arrangement of panels, and arguments passed to contour.im to control the display of each panel.

Value

Null.

Details

This is a method for the generic command contour for the class "imlist". An object of class "imlist" represents a list of pixel images.

(The outdated class "listof" is also handled.)

Each entry in the list x will be displayed as a contour plot, in an array of panels laid out on the same graphics display, using plot.solist. Invididual panels are plotted by contour.im.

See Also

plot.solist, contour.im

Examples

Run this code
# NOT RUN {
# Multitype point pattern
 contour(D <- density(split(amacrine)))
# }

Run the code above in your browser using DataLab