"fv"
to the same values of the function argument.harmonise.fv(...)
harmonize.fv(...)"fv")....,
whose entries are objects of class "fv".
If the arguments were named (name=value) then the return value
also carries these names."fv") is
essentially a data frame giving the values of a function $f(x)$
(or several alternative estimates of this value)
at equally-spaced values of the function argument $x$. This command makes any number of "fv" objects compatible,
in the loose sense that they have the same sequence of values of
$x$. They can then be combined by cbind.fv,
but not necessarily by eval.fv.
All arguments ... must be function value tables
(objects of class "fv").
The result will be a list, of length equal to the number of
arguments ..., containing new versions of each of these functions,
converted to a common sequence of $x$ values.
If the arguments were named (name=value) then the return value
also carries these names.
The range of $x$ values in the resulting functions
will be the intersection of the ranges of $x$ values
in the original functions.
The spacing of $x$ values in the resulting functions
will be the finest (narrowest) of the spacings of the
$x$ values in the original functions.
Function values are interpolated using approxfun.
The resulting objects are not guaranteed to be compatible
in the strict sense of compatible.fv,
so they cannot necessarily be combined using eval.fv
or collapse.fv.
fv.object,
cbind.fv,
eval.fv,
compatible.fvH <- harmonise.fv(K=Kest(cells), G=Gest(cells))
H
## generates a warning about duplicated columns
cbind(H$K, H$G)Run the code above in your browser using DataLab