Learn R Programming

spatstat (version 1.64-1)

pcfcross.inhom: Inhomogeneous Multitype Pair Correlation Function (Cross-Type)

Description

Estimates the inhomogeneous cross-type pair correlation function for a multitype point pattern.

Usage

pcfcross.inhom(X, i, j, lambdaI = NULL, lambdaJ = NULL, ...,
               r = NULL, breaks = NULL,
               kernel="epanechnikov", bw=NULL, stoyan=0.15,
               correction = c("isotropic", "Ripley", "translate"),
               sigma = NULL, varcov = NULL)

Arguments

X

The observed point pattern, from which an estimate of the inhomogeneous cross-type pair correlation function \(g_{ij}(r)\) will be computed. It must be a multitype point pattern (a marked point pattern whose marks are a factor).

i

The type (mark value) of the points in X from which distances are measured. A character string (or something that will be converted to a character string). Defaults to the first level of marks(X).

j

The type (mark value) of the points in X to which distances are measured. A character string (or something that will be converted to a character string). Defaults to the second level of marks(X).

lambdaI

Optional. Values of the estimated intensity function of the points of type i. Either a vector giving the intensity values at the points of type i, a pixel image (object of class "im") giving the intensity values at all locations, or a function(x,y) which can be evaluated to give the intensity value at any location.

lambdaJ

Optional. Values of the estimated intensity function of the points of type j. A numeric vector, pixel image or function(x,y).

r

Vector of values for the argument \(r\) at which \(g_{ij}(r)\) should be evaluated. There is a sensible default.

breaks

This argument is for internal use only.

kernel

Choice of smoothing kernel, passed to density.default.

bw

Bandwidth for smoothing kernel, passed to density.default.

…

Other arguments passed to the kernel density estimation function density.default.

stoyan

Bandwidth coefficient; see Details.

correction

Choice of edge correction.

sigma,varcov

Optional arguments passed to density.ppp to control the smoothing bandwidth, when lambdaI or lambdaJ is estimated by kernel smoothing.

Value

A function value table (object of class "fv"). Essentially a data frame containing the variables

r

the vector of values of the argument \(r\) at which the inhomogeneous cross-type pair correlation function \(g_{ij}(r)\) has been estimated

theo

vector of values equal to 1, the theoretical value of \(g_{ij}(r)\) for the Poisson process

trans

vector of values of \(g_{ij}(r)\) estimated by translation correction

iso

vector of values of \(g_{ij}(r)\) estimated by Ripley isotropic correction

as required.

Details

The inhomogeneous cross-type pair correlation function \(g_{ij}(r)\) is a summary of the dependence between two types of points in a multitype spatial point process that does not have a uniform density of points.

The best intuitive interpretation is the following: the probability \(p(r)\) of finding two points, of types \(i\) and \(j\) respectively, at locations \(x\) and \(y\) separated by a distance \(r\) is equal to $$ p(r) = \lambda_i(x) lambda_j(y) g(r) \,{\rm d}x \, {\rm d}y $$ where \(\lambda_i\) is the intensity function of the process of points of type \(i\). For a multitype Poisson point process, this probability is \(p(r) = \lambda_i(x) \lambda_j(y)\) so \(g_{ij}(r) = 1\).

The command pcfcross.inhom estimates the inhomogeneous pair correlation using a modified version of the algorithm in pcf.ppp.

If the arguments lambdaI and lambdaJ are missing or null, they are estimated from X by kernel smoothing using a leave-one-out estimator.

See Also

pcf.ppp, pcfinhom, pcfcross, pcfdot.inhom

Examples

Run this code
# NOT RUN {
  data(amacrine)
  plot(pcfcross.inhom(amacrine, "on", "off", stoyan=0.1),
       legendpos="bottom")
# }

Run the code above in your browser using DataLab