Learn R Programming

spatstat (version 1.56-1)

plot.textstring: Plot a Text String

Description

Plots an object of class "textstring".

Usage

# S3 method for textstring
plot(x, …, do.plot = TRUE)

Arguments

x

Object of class "textstring" to be plotted. This object is created by the command textstring.

…

Additional graphics arguments passed to text to control the plotting of text.

do.plot

Logical value indicating whether to actually plot the text.

Value

A window (class "owin") enclosing the plotted graphics.

Details

The argument x should be an object of class "textstring" created by the command textstring.

This function displays the text using text.

See Also

onearrow, yardstick

Examples

Run this code
# NOT RUN {
  W <- Window(humberside)
  te <- textstring(centroid.owin(W), txt="Humberside", cex=2.5)
  te
  plot(layered(W, te), main="")
# }

Run the code above in your browser using DataLab