## S3 method for class 'im':
contour(x, \dots, main,
axes=FALSE, add=FALSE, col=par("fg"),
clipwin=NULL, show.all=!add, do.plot=TRUE)"im".TRUE, coordinate axes are plotted
(with tick marks) around a region slightly larger than the image window.
If FALSE (the default), no axes are plotted,
and a box is drawn tightly around the image window.
FALSE, a new plot is created. If TRUE,
the contours are drawn over the existing plot.colourmap object."owin").
Only this subset of the data will be displayed.contour.default
controlling the contour plot; see Details.axis=TRUE) coordinate axis markings.
Default is TRUE for new plots and FALSE for added plots.contour function,
for objects of the class "im".
An object of class "im" represents a pixel image;
see im.object. This function displays the values of the pixel image x
as a contour plot on the current plot device,
using equal scales on the $x$ and $y$ axes.
The appearance of the plot can be modified
using any of the arguments listed in the help for
contour.default.
Useful ones include:
[object Object],[object Object],[object Object]
See contour.default for a full list of these arguments.
The defaults for any of the abovementioned arguments
can be reset using spatstat.options("par.contour").
If col is a colour map (object of class "colourmap",
see colourmap) then the contours will be plotted in
different colours as determined by the colour map.
The contour at level z will be plotted
in the colour col(z) associated with this level in the colour map.
im.object,
plot.im,
persp.im# an image
Z <- setcov(owin())
contour(Z, axes=TRUE)
contour(Z)
co <- colourmap(rainbow(100), range=c(0,1))
contour(Z, col=co, lwd=2)Run the code above in your browser using DataLab