Given two point patterns,
this function computes the Euclidean distance from each point
in the first pattern to each point in the second pattern,
and returns a matrix containing these distances. This is a method for the generic function crossdist
for point patterns (objects of class "ppp").
This function expects two
point patterns X and Y, and returns the matrix
whose [i,j] entry is the distance from X[i] to
Y[j].
The argument method is not normally used. It is
retained only for checking the validity of the software.
If method = "interpreted" then the distances are
computed using interpreted R code only. If method="C"
(the default) then C code is used.
The C code is faster by a factor of 4.